// Assert.cpp
// Copyright (C) 2010 Miguel Vargas (miguel.vargas@gmail.com)
//
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Library General Public
// License as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Library General Public License for more details.
//
// You should have received a copy of the GNU Library General Public
// License along with this library; if not, write to the Free
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

#include <Basic/Assert.h>


#if defined WIN32
	#define WIN32_LEAN_AND_MEAN
	#define NOSERVICE
	#define NOMCX
	#define NOIME
	#include <windows.h>


	void AssertFail(const char* function, const char* condition, const char* source, const char* line) throw()
	{
		OutputDebugString("Assert fail");
		OutputDebugString("\n- Function: ");
		OutputDebugString(function);
		OutputDebugString("\n- Condition: ");
		OutputDebugString(condition);
		OutputDebugString("\n- Source file: ");
		OutputDebugString(source);
		OutputDebugString("\n- Line: ");
		OutputDebugString(line);
		OutputDebugString("\n");

		DebugBreak();
	}
#else
	#include <stdio.h>
	#include <signal.h>


	void AssertFail(const char* function, const char* condition, const char* source, const char* line) throw()
	{
		fputs("Assert fail", stderr);
		fputs("\n- Function: ", stderr);
		fputs(function, stderr);
		fputs("\n- Condition: ", stderr);
		fputs(condition, stderr);
		fputs("\n- Source file: ", stderr);
		fputs(source, stderr);
		fputs("\n- Line: ", stderr);
		fputs(line, stderr);
		fputs("\n", stderr);

		raise(SIGINT);
	}
#endif
