// Debug.cpp
// Copyright (C) 2010 Miguel Vargas (miguel.vargas@gmail.com)
//
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Library General Public
// License as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Library General Public License for more details.
//
// You should have received a copy of the GNU Library General Public
// License along with this library; if not, write to the Free
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

#include <Basic/Debug.h>


#if defined WIN32
	#define WIN32_LEAN_AND_MEAN
	#define NOSERVICE
	#define NOMCX
	#define NOIME
	#include <windows.h>


	void DebugMessage(const char* message) throw()
	{
		OutputDebugString(message);
	}


	void DebugMessage(const char* type, const char* message, const char* source, const char* line, const char* function) throw()
	{
		OutputDebugString("{");
		OutputDebugString(type);
		OutputDebugString("}");
		if (message)
		{
			OutputDebugString(" \"");
			OutputDebugString(message);
			OutputDebugString("\",");
		}
		OutputDebugString(" Source: \"");
		OutputDebugString(source);
		OutputDebugString("\", Line: ");
		OutputDebugString(line);
		OutputDebugString(", Function: ");
		OutputDebugString(function);
		OutputDebugString("\n");
	}


	void DebugStop() throw()
	{
		DebugBreak();
	}
#else
	#include <stdio.h>
	#include <signal.h>


	void DebugMessage(const char* message) throw()
	{
		fputs(message, stderr);
	}


	void DebugMessage(const char* type, const char* message, const char* file_name, const char* line, const char* function) throw()
	{
		fputs("{", stderr);
		fputs(type, stderr);
		fputs("}", stderr);
		if (message)
		{
			fputs(" \"", stderr);
			fputs(message, stderr);
			fputs("\"", stderr);
		}
		fputs(" Source: \"", stderr);
		fputs(file_name, stderr);
		fputs("\", Line: ", stderr);
		fputs(line, stderr);
		fputs(", Function: ", stderr);
		fputs(function, stderr);
		fputs("\n", stderr);
	}


	void DebugStop() throw()
	{
		raise(SIGINT);
	}
#endif
